#pragma once

// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include <Corrade/Containers/Array.h>
#include <Corrade/Containers/ArrayView.h>
#include <Corrade/Containers/Pointer.h>
#include <Corrade/Containers/StringView.h>

#include "../Gvas.h"
#include "../../BinaryIo/BinaryIo.h"
#include "../Types/UnrealPropertyBase.h"

using namespace Corrade;

namespace Gvas { namespace Serialisers {

using PropertyArray = Containers::Array<Types::UnrealPropertyBase::ptr>;
using PropertyArrayView = Containers::ArrayView<Types::UnrealPropertyBase::ptr>;
using StringArrayView = Containers::ArrayView<const Containers::String>;

class AbstractUnrealCollectionProperty {
    public:
        using ptr = Containers::Pointer<AbstractUnrealCollectionProperty>;

        virtual ~AbstractUnrealCollectionProperty() = default;

        virtual auto types() -> StringArrayView = 0;

        virtual auto deserialise(Containers::StringView name, Containers::StringView type, std::size_t value_length,
                                 std::uint32_t count, BinaryIo::Reader& reader, PropertySerialiser& serialiser)
                                 -> PropertyArray = 0;

        virtual bool serialise(PropertyArrayView props, Containers::StringView item_type,
                               std::size_t& bytes_written, BinaryIo::Writer& writer,
                               PropertySerialiser& serialiser) = 0;
};

}}
