// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include "../../BinaryIo/Reader.h"
#include "../../BinaryIo/Writer.h"
#include "../../Logger/Logger.h"

#include "BoolProperty.h"

namespace Gvas { namespace Serialisers {

StringArrayView
BoolProperty::types() {
    using namespace Containers::Literals;
    static const Containers::Array<Containers::String> types{InPlaceInit, {"BoolProperty"_s}};
    return types;
}

Types::UnrealPropertyBase::ptr
BoolProperty::deserialise(Containers::StringView name, Containers::StringView type, std::size_t value_length,
                          BinaryIo::Reader& reader, PropertySerialiser& serialiser)
{
    if(value_length != 0) {
        LOG_ERROR_FORMAT("Invalid value length for bool property {}. Expected 0, got {} instead.", name, value_length);
        return nullptr;
    }

    std::int16_t value;
    if(!reader.readInt16(value)) {
        LOG_ERROR_FORMAT("Couldn't read bool property {}'s value.", name);
        return nullptr;
    }

    if(value > 1 || value < 0) {
        LOG_ERROR_FORMAT("Bool property {}'s value is invalid. Expected 1 or 0, got {} instead.", name, value);
        return nullptr;
    }

    auto prop = Containers::pointer<Types::BoolProperty>();
    prop->value = value;

    return prop;
}

bool
BoolProperty::serialise(Types::UnrealPropertyBase::ptr& prop, std::size_t& bytes_written, BinaryIo::Writer& writer,
                        PropertySerialiser& serialiser)
{
    auto bool_prop = dynamic_cast<Types::BoolProperty*>(prop.get());
    if(!bool_prop) {
        LOG_ERROR("The property is not a valid bool property.");
        return false;
    }

    writer.writeValueToArray<std::int16_t>(std::int16_t(bool_prop->value));

    return true;
}

}}
