// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include "../../BinaryIo/Reader.h"
#include "../../BinaryIo/Writer.h"
#include "../../Logger/Logger.h"

#include "GuidProperty.h"

using namespace Containers::Literals;

namespace Gvas { namespace Serialisers {

Types::UnrealPropertyBase::ptr
GuidProperty::deserialiseProperty(Containers::StringView name, Containers::StringView type, std::size_t value_length,
                                  BinaryIo::Reader& reader, PropertySerialiser& serialiser)
{
    auto prop = Containers::pointer<Types::GuidStructProperty>();

    if(!reader.readStaticArray(prop->guid)) {
        LOG_ERROR_FORMAT("Couldn't read GUID property {}'s value.", name);
        return nullptr;
    }

    return prop;
}

bool
GuidProperty::serialiseProperty(Types::UnrealPropertyBase::ptr& prop, std::size_t& bytes_written,
                                BinaryIo::Writer& writer, PropertySerialiser& serialiser)
{
    auto guid_prop = dynamic_cast<Types::GuidStructProperty*>(prop.get());
    if(!guid_prop) {
        LOG_ERROR("The property is not a valid GUID property.");
        return false;
    }

    bytes_written += writer.writeDataToArray<char>({guid_prop->guid.data(), guid_prop->guid.size()});

    return true;
}

}}
