// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include "../../BinaryIo/Reader.h"
#include "../../BinaryIo/Writer.h"
#include "../../Logger/Logger.h"

#include "IntProperty.h"

namespace Gvas { namespace Serialisers {

Types::UnrealPropertyBase::ptr
IntProperty::deserialiseProperty(Containers::StringView name, Containers::StringView type, std::size_t value_length,
                                 BinaryIo::Reader& reader, PropertySerialiser& serialiser)
{
    auto prop = Containers::pointer<Types::IntProperty>();

    if(value_length == std::size_t(-1)) {
        if(!reader.readInt32(prop->value)) {
            LOG_ERROR("Couldn't read int property's value.");
            return nullptr;
        }

        prop->valueLength = std::size_t(-1);
        return prop;
    }

    char terminator;
    if(!reader.readChar(terminator) || terminator != '\0') {
        LOG_ERROR_FORMAT("Couldn't read a null byte in int property {}.", name);
        return nullptr;
    }

    if(!reader.readInt32(prop->value)) {
        LOG_ERROR_FORMAT("Couldn't read int property {}'s value.", name);
        return nullptr;
    }

    prop->name.emplace(name);

    return prop;
}

bool
IntProperty::serialiseProperty(Types::UnrealPropertyBase::ptr& prop, std::size_t& bytes_written,
                               BinaryIo::Writer& writer, PropertySerialiser& serialiser)
{
    auto int_prop = dynamic_cast<Types::IntProperty*>(prop.get());
    if(!int_prop) {
        LOG_ERROR("The property is not a valid int property.");
        return false;
    }

    if(prop->valueLength != std::size_t(-1)) {
        writer.writeValueToArray<char>('\0');
    }

    bytes_written += writer.writeValueToArray<std::int32_t>(int_prop->value);

    return true;
}

}}
