// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include "../../BinaryIo/Reader.h"
#include "../../BinaryIo/Writer.h"
#include "../../Logger/Logger.h"

#include "RotatorProperty.h"

namespace Gvas { namespace Serialisers {

Types::UnrealPropertyBase::ptr
RotatorProperty::deserialiseProperty(Containers::StringView name, Containers::StringView type, std::size_t value_length,
                                     BinaryIo::Reader& reader, PropertySerialiser& serialiser)
{
    auto prop = Containers::pointer<Types::RotatorStructProperty>();

    if(!reader.readFloat(prop->x) || !reader.readFloat(prop->y) || !reader.readFloat(prop->z)) {
        LOG_ERROR_FORMAT("Couldn't read rotator property {}'s value.", name);
        return nullptr;
    }

    return prop;
}

bool
RotatorProperty::serialiseProperty(Types::UnrealPropertyBase::ptr& prop, std::size_t& bytes_written,
                                   BinaryIo::Writer& writer, PropertySerialiser& serialiser)
{
    auto rotator = dynamic_cast<Types::RotatorStructProperty*>(prop.get());
    if(!rotator) {
        LOG_ERROR("The property is not a valid rotator property.");
        return false;
    }

    bytes_written += writer.writeValueToArray<float>(rotator->x) +
                     writer.writeValueToArray<float>(rotator->y) +
                     writer.writeValueToArray<float>(rotator->z);

    return true;
}

}}
