// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include "../../BinaryIo/Reader.h"
#include "../../BinaryIo/Writer.h"
#include "../../Logger/Logger.h"

#include "StringProperty.h"

namespace Gvas { namespace Serialisers {

StringArrayView
StringProperty::types() {
    using namespace Containers::Literals;
    static const Containers::Array<Containers::String> types{InPlaceInit, {
        "NameProperty"_s, "StrProperty"_s, "SoftObjectProperty"_s, "ObjectProperty"_s
    }};
    return types;
}

Types::UnrealPropertyBase::ptr
StringProperty::deserialise(Containers::StringView name, Containers::StringView type, std::size_t value_length,
                            BinaryIo::Reader& reader, PropertySerialiser& serialiser)
{
    auto prop = Containers::pointer<Types::StringProperty>(type);

    if(value_length != std::size_t(-1)) {
        char terminator;
        if(!reader.readChar(terminator) || terminator != '\0') {
            LOG_ERROR_FORMAT("Couldn't read a null byte in string property {}.", name);
            return nullptr;
        }
    }

    if(!reader.readUEString(prop->value)) {
        LOG_ERROR_FORMAT("Couldn't read string property {}'s value.", name);
        return nullptr;
    }

    prop->valueLength = value_length;

    return prop;
}

bool
StringProperty::serialise(Types::UnrealPropertyBase::ptr& prop, std::size_t& bytes_written, BinaryIo::Writer& writer,
                          PropertySerialiser& serialiser)
{
    auto str_prop = dynamic_cast<Types::StringProperty*>(prop.get());
    if(!str_prop) {
        LOG_ERROR("The property is not a valid string property.");
        return false;
    }

    if(str_prop->valueLength != std::size_t(-1)) {
        writer.writeValueToArray<char>('\0');
    }

    bytes_written += writer.writeUEStringToArray(str_prop->value);

    return true;
}

}}
