#pragma once

// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include <type_traits>

#include <Corrade/Containers/Array.h>
#include <Corrade/Containers/ArrayView.h>
#include <Corrade/Containers/StringView.h>

#include "AbstractUnrealProperty.h"
#include "../Types/StructProperty.h"

namespace Gvas { namespace Serialisers {

template<typename T>
class UnrealProperty : public AbstractUnrealProperty {
    static_assert(std::is_base_of<Types::UnrealPropertyBase, T>::value, "T must be derived from UnrealPropertyBase.");

    public:
        using ptr = Containers::Pointer<UnrealProperty<T>>;

        auto types() -> StringArrayView override {
            static const Containers::Array<Containers::String> types = []{
                Containers::Array<Containers::String> array;
                Containers::Pointer<T> p(new T);
                if(std::is_base_of<Types::StructProperty, T>::value) {
                    array = Containers::Array<Containers::String>{InPlaceInit, {
                        dynamic_cast<Types::StructProperty*>(p.get())->structType
                    }};
                }
                else {
                    array = Containers::Array<Containers::String>{InPlaceInit, {p->propertyType}};
                }
                return array;
            }();
            return types;
        }

        auto deserialise(Containers::StringView name, Containers::StringView type, std::size_t value_length,
                         BinaryIo::Reader& reader, PropertySerialiser& serialiser)
                         -> Types::UnrealPropertyBase::ptr override
        {
            return deserialiseProperty(name, type, value_length, reader, serialiser);
        }

        bool serialise(Types::UnrealPropertyBase::ptr& prop, std::size_t& bytes_written, BinaryIo::Writer& writer,
                       PropertySerialiser& serialiser) override
        {
            return serialiseProperty(prop, bytes_written, writer, serialiser);
        }

    private:
        virtual auto deserialiseProperty(Containers::StringView name, Containers::StringView type,
                                         std::size_t value_length, BinaryIo::Reader& reader,
                                         PropertySerialiser& serialiser) -> Types::UnrealPropertyBase::ptr = 0;

        virtual bool serialiseProperty(Types::UnrealPropertyBase::ptr& prop, std::size_t& bytes_written,
                                       BinaryIo::Writer& writer, PropertySerialiser& serialiser) = 0;
};

}}
