#pragma once

// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include <cstdint>

#include <map>

#include <Corrade/Containers/StringView.h>

using namespace Corrade;
using namespace Containers::Literals;

namespace mbst { namespace GameData {

struct Accessory {
    Containers::StringView name;
    enum Size {
        S,
        M,
        L,
        XL
    };
    Size size{};
};

static const std::map<std::int32_t, Accessory> accessories{
    // region Primitives
    {1,    {"Cube"_s,                   Accessory::Size::S}},
    {2,    {"Pentagon"_s,               Accessory::Size::S}},
    {3,    {"Hexagon"_s,                Accessory::Size::S}},
    {4,    {"Cylinder"_s,               Accessory::Size::S}},
    {5,    {"Sphere"_s,                 Accessory::Size::S}},
    {6,    {"TriPyramid"_s,             Accessory::Size::S}},
    {7,    {"SquPyramid"_s,             Accessory::Size::S}},
    {8,    {"PenPyramid"_s,             Accessory::Size::S}},
    {9,    {"HexPyramid"_s,             Accessory::Size::S}},
    {10,   {"Cone"_s,                   Accessory::Size::S}},
    {11,   {"SquStick"_s,               Accessory::Size::S}},
    {12,   {"PenStick"_s,               Accessory::Size::S}},
    {13,   {"HexStick"_s,               Accessory::Size::S}},
    {14,   {"CycStick"_s,               Accessory::Size::S}},
    {15,   {"Capsule"_s,                Accessory::Size::S}},
    {16,   {"Decal Pad 01"_s,           Accessory::Size::S}},
    {17,   {"Decal Pad 02"_s,           Accessory::Size::S}},
    {18,   {"Decal Pad 03"_s,           Accessory::Size::S}},
    {19,   {"Decal Pad 04"_s,           Accessory::Size::S}},
    {20,   {"Decal Pad 05"_s,           Accessory::Size::S}},
    {21,   {"Triangle"_s,               Accessory::Size::S}},
    {22,   {"ThinStar"_s,               Accessory::Size::S}},
    {23,   {"Star"_s,                   Accessory::Size::S}},
    {24,   {"SixSideStar"_s,            Accessory::Size::S}},
    {25,   {"Asterisk"_s,               Accessory::Size::S}},
    {26,   {"Ring"_s,                   Accessory::Size::S}},
    {27,   {"SawedRing"_s,              Accessory::Size::S}},
    {28,   {"HalfRing"_s,               Accessory::Size::S}},
    {29,   {"Cresent"_s,                Accessory::Size::S}},
    {30,   {"Donut"_s,                  Accessory::Size::S}},
    {31,   {"FiveCogWheel"_s,           Accessory::Size::S}},
    {32,   {"SixCogWheel"_s,            Accessory::Size::S}},
    {33,   {"SevenCogWheel"_s,          Accessory::Size::S}},
    {34,   {"EightCogWheel"_s,          Accessory::Size::S}},
    {35,   {"TwelveCogWheel"_s,         Accessory::Size::S}},

    {51,   {"SquBevel"_s,               Accessory::Size::S}},
    {52,   {"TriBevel"_s,               Accessory::Size::S}},
    {53,   {"PenBevel"_s,               Accessory::Size::S}},
    {54,   {"HexBevel"_s,               Accessory::Size::S}},
    {55,   {"CycBevel"_s,               Accessory::Size::S}},
    {56,   {"RecBevel"_s,               Accessory::Size::S}},
    {57,   {"DaiBevel"_s,               Accessory::Size::S}},
    {58,   {"MonBevel"_s,               Accessory::Size::S}},
    {59,   {"CofBevel"_s,               Accessory::Size::S}},
    {60,   {"JevBevel"_s,               Accessory::Size::S}},
    {61,   {"SquEmboss"_s,              Accessory::Size::S}},
    {62,   {"TriEmboss"_s,              Accessory::Size::S}},
    {63,   {"PenEmboss"_s,              Accessory::Size::S}},
    {64,   {"HexEmboss"_s,              Accessory::Size::S}},
    {65,   {"CycEmboss"_s,              Accessory::Size::S}},
    {66,   {"RecEmboss"_s,              Accessory::Size::S}},
    {67,   {"DaiEmboss"_s,              Accessory::Size::S}},
    {68,   {"MonEmboss"_s,              Accessory::Size::S}},
    {69,   {"CofEmboss"_s,              Accessory::Size::S}},
    {70,   {"JevEmboss"_s,              Accessory::Size::S}},

    {101,  {"Flat Hex Pin"_s,           Accessory::Size::S}},
    {102,  {"Cross Circle Pin"_s,       Accessory::Size::S}},
    {103,  {"Flat Circle Pin"_s,        Accessory::Size::S}},
    {104,  {"Hex Circle Pin"_s,         Accessory::Size::S}},
    {105,  {"Circle Button Pin"_s,      Accessory::Size::S}},
    {106,  {"Hexagon Pin"_s,            Accessory::Size::S}},
    {107,  {"Cross Square Pin"_s,       Accessory::Size::S}},
    {108,  {"Flat Square Pin"_s,        Accessory::Size::S}},
    {109,  {"Quad Corner Pin"_s,        Accessory::Size::S}},
    {110,  {"Bi Corner Pin"_s,          Accessory::Size::S}},
    {111,  {"Circle Pin"_s,             Accessory::Size::S}},
    {112,  {"Flat End Pin"_s,           Accessory::Size::S}},
    {113,  {"Flat Cut Pin"_s,           Accessory::Size::S}},
    {114,  {"Radial Pin"_s,             Accessory::Size::S}},
    {115,  {"Diamiter Pin"_s,           Accessory::Size::S}},

    {151,  {"TriPoint"_s,               Accessory::Size::S}},
    {152,  {"SquPoint"_s,               Accessory::Size::S}},
    {153,  {"PenPoint"_s,               Accessory::Size::S}},
    {154,  {"HexPoint"_s,               Accessory::Size::S}},
    {155,  {"CycPoint"_s,               Accessory::Size::S}},
    {156,  {"Bevel SquCutPoint"_s,      Accessory::Size::S}},
    {157,  {"Bevel HexCutPoint"_s,      Accessory::Size::S}},
    {158,  {"Bevel HexPoint"_s,         Accessory::Size::S}},
    {159,  {"Bevel CycCutPoint"_s,      Accessory::Size::S}},
    {160,  {"Bevel CycPoint"_s,         Accessory::Size::S}},

    {201,  {"Shaped Edge 01"_s,         Accessory::Size::M}},
    {202,  {"Shaped Edge 02"_s,         Accessory::Size::M}},
    {203,  {"Shaped Edge 03"_s,         Accessory::Size::M}},
    {204,  {"Shaped Edge 04"_s,         Accessory::Size::M}},
    {205,  {"Shaped Edge 05"_s,         Accessory::Size::M}},
    {206,  {"Shaped Edge 06"_s,         Accessory::Size::M}},
    {207,  {"Shaped Edge 07"_s,         Accessory::Size::M}},
    {208,  {"Shaped Edge 08"_s,         Accessory::Size::M}},
    {209,  {"Shaped Edge 09"_s,         Accessory::Size::M}},
    {210,  {"Shaped Edge 10"_s,         Accessory::Size::M}},
    {211,  {"Shaped Edge 11"_s,         Accessory::Size::M}},
    {212,  {"Shaped Edge 12"_s,         Accessory::Size::M}},
    {213,  {"Shaped Edge 13"_s,         Accessory::Size::M}},
    {214,  {"Shaped Edge 14"_s,         Accessory::Size::M}},
    {215,  {"Shaped Edge 15"_s,         Accessory::Size::M}},
    {216,  {"Shaped Edge 16"_s,         Accessory::Size::M}},
    {217,  {"Shaped Edge 17"_s,         Accessory::Size::M}},
    {218,  {"Shaped Edge 18"_s,         Accessory::Size::M}},
    {219,  {"Shaped Edge 19"_s,         Accessory::Size::M}},
    {220,  {"Shaped Edge 20"_s,         Accessory::Size::M}},

    {251,  {"Fish Tail 01"_s,           Accessory::Size::M}},
    {252,  {"Fish Tail 02"_s,           Accessory::Size::M}},
    {253,  {"Fish Tail 03"_s,           Accessory::Size::M}},
    {254,  {"Fish Tail 04"_s,           Accessory::Size::M}},
    {255,  {"Fish Tail 05"_s,           Accessory::Size::M}},
    {256,  {"Based Separator 01"_s,     Accessory::Size::M}},
    {257,  {"Based Separator 02"_s,     Accessory::Size::M}},
    {258,  {"Based Separator 03"_s,     Accessory::Size::M}},
    {259,  {"Based Separator 04"_s,     Accessory::Size::M}},
    {260,  {"Based Separator 05"_s,     Accessory::Size::M}},
    {261,  {"Based Separator 06"_s,     Accessory::Size::M}},
    {262,  {"Based Separator 07"_s,     Accessory::Size::M}},
    {263,  {"Based Separator 08"_s,     Accessory::Size::M}},
    {264,  {"Based Separator 09"_s,     Accessory::Size::M}},
    {265,  {"Based Separator 10"_s,     Accessory::Size::M}},

    {301,  {"Rectangular Box 01"_s,     Accessory::Size::M}},
    {302,  {"Rectangular Box 02"_s,     Accessory::Size::M}},
    {303,  {"Rectangular Box 03"_s,     Accessory::Size::M}},
    {304,  {"Rectangular Box 04"_s,     Accessory::Size::M}},
    {305,  {"Rectangular Box 05"_s,     Accessory::Size::M}},
    {306,  {"CofBox 01"_s,              Accessory::Size::M}},
    {307,  {"CofBox 02"_s,              Accessory::Size::M}},
    {308,  {"CofBox 03"_s,              Accessory::Size::M}},
    {309,  {"CofBox 04"_s,              Accessory::Size::M}},
    {310,  {"CofBox 05"_s,              Accessory::Size::M}},
    {311,  {"Triangular Box 01"_s,      Accessory::Size::M}},
    {312,  {"Triangular Box 02"_s,      Accessory::Size::M}},
    {313,  {"Triangular Box 03"_s,      Accessory::Size::M}},
    {314,  {"Triangular Box 04"_s,      Accessory::Size::M}},
    {315,  {"Triangular Box 05"_s,      Accessory::Size::M}},
    {316,  {"Diagonal Box A01"_s,       Accessory::Size::M}},
    {317,  {"Diagonal Box A02"_s,       Accessory::Size::M}},
    {318,  {"Diagonal Box A03"_s,       Accessory::Size::M}},
    {319,  {"Diagonal Box A04"_s,       Accessory::Size::M}},
    {320,  {"Diagonal Box A05"_s,       Accessory::Size::M}},
    {321,  {"Diagonal Box B01"_s,       Accessory::Size::M}},
    {322,  {"Diagonal Box B02"_s,       Accessory::Size::M}},
    {323,  {"Diagonal Box B03"_s,       Accessory::Size::M}},
    {324,  {"Diagonal Box B04"_s,       Accessory::Size::M}},
    {325,  {"Diagonal Box B05"_s,       Accessory::Size::M}},
    // endregion

    // region Armours
    {1001, {"Short Layer 01"_s,         Accessory::Size::M}},
    {1002, {"Short Layer 02"_s,         Accessory::Size::M}},
    {1003, {"Short Layer 03"_s,         Accessory::Size::M}},
    {1004, {"Short Layer 04"_s,         Accessory::Size::M}},
    {1005, {"Short Layer 05"_s,         Accessory::Size::M}},
    {1006, {"Long Layer 01"_s,          Accessory::Size::M}},
    {1007, {"Long Layer 02"_s,          Accessory::Size::M}},
    {1008, {"Long Layer 03"_s,          Accessory::Size::M}},
    {1009, {"Long Layer 04"_s,          Accessory::Size::M}},
    {1010, {"Long Layer 05"_s,          Accessory::Size::M}},
    {1011, {"Diagonal Long Layer 01"_s, Accessory::Size::M}},
    {1012, {"Diagonal Long Layer 02"_s, Accessory::Size::M}},
    {1013, {"Diagonal Long Layer 03"_s, Accessory::Size::M}},
    {1014, {"Diagonal Long Layer 04"_s, Accessory::Size::M}},
    {1015, {"Diagonal Long Layer 05"_s, Accessory::Size::M}},

    {1051, {"Sloped Layer 01"_s,        Accessory::Size::M}},
    {1052, {"Sloped Layer 02"_s,        Accessory::Size::M}},
    {1053, {"Sloped Layer 03"_s,        Accessory::Size::M}},
    {1054, {"Sloped Layer 04"_s,        Accessory::Size::M}},
    {1055, {"Sloped Layer 05"_s,        Accessory::Size::M}},
    {1056, {"Sloped Layer 06"_s,        Accessory::Size::M}},
    {1057, {"Sloped Layer 07"_s,        Accessory::Size::M}},
    {1058, {"Sloped Layer 08"_s,        Accessory::Size::M}},
    {1059, {"Sloped Layer 09"_s,        Accessory::Size::M}},
    {1060, {"Sloped Layer 10"_s,        Accessory::Size::M}},
    {1061, {"Sloped Layer 11"_s,        Accessory::Size::M}},
    {1062, {"Sloped Layer 12"_s,        Accessory::Size::M}},
    {1063, {"Sloped Layer 13"_s,        Accessory::Size::M}},
    {1064, {"Sloped Layer 14"_s,        Accessory::Size::M}},
    {1065, {"Sloped Layer 15"_s,        Accessory::Size::M}},

    {1101, {"Raised Center 01"_s,       Accessory::Size::M}},
    {1102, {"Raised Center 02"_s,       Accessory::Size::M}},
    {1103, {"Raised Center 03"_s,       Accessory::Size::M}},
    {1104, {"Raised Center 04"_s,       Accessory::Size::M}},
    {1105, {"Raised Center 05"_s,       Accessory::Size::M}},
    {1106, {"Raised Block 01"_s,        Accessory::Size::M}},
    {1107, {"Raised Block 02"_s,        Accessory::Size::M}},
    {1108, {"Raised Block 03"_s,        Accessory::Size::M}},
    {1109, {"Raised Pointed"_s,         Accessory::Size::M}},
    {1110, {"Raised Cover"_s,           Accessory::Size::M}},
    {1111, {"Raised Slant 01"_s,        Accessory::Size::M}},
    {1112, {"Raised Slant 02"_s,        Accessory::Size::M}},
    {1113, {"Raised Slant 03"_s,        Accessory::Size::M}},
    {1114, {"Raised Slant 04"_s,        Accessory::Size::M}},
    {1115, {"Raised Slant 05"_s,        Accessory::Size::M}},

    {1151, {"Wide Patch 01"_s,          Accessory::Size::L}},
    {1152, {"Wide Patch 02"_s,          Accessory::Size::L}},
    {1153, {"Wide Patch 03"_s,          Accessory::Size::L}},
    {1154, {"Wide Patch 04"_s,          Accessory::Size::L}},
    {1155, {"Wide Patch 05"_s,          Accessory::Size::L}},

    {1201, {"Pointed Armour 01"_s,      Accessory::Size::L}},
    {1202, {"Pointed Armour 02"_s,      Accessory::Size::L}},
    {1203, {"Pointed Armour 03"_s,      Accessory::Size::L}},
    {1204, {"Pointed Armour 04"_s,      Accessory::Size::L}},
    {1205, {"Pointed Armour 05"_s,      Accessory::Size::L}},
    {1206, {"Pointed Armour 06"_s,      Accessory::Size::L}},
    {1207, {"Pointed Armour 07"_s,      Accessory::Size::L}},
    {1208, {"Pointed Armour 08"_s,      Accessory::Size::L}},
    {1209, {"Pointed Armour 09"_s,      Accessory::Size::L}},
    {1210, {"Pointed Armour 10"_s,      Accessory::Size::L}},
    {1211, {"Pointed Armour 11"_s,      Accessory::Size::L}},
    {1212, {"Pointed Armour 12"_s,      Accessory::Size::L}},
    {1213, {"Pointed Armour 13"_s,      Accessory::Size::L}},
    {1214, {"Pointed Armour 14"_s,      Accessory::Size::L}},
    {1215, {"Pointed Armour 15"_s,      Accessory::Size::L}},

    {1251, {"E Limb Cover 01"_s,        Accessory::Size::L}},
    {1252, {"E Limb Cover 02"_s,        Accessory::Size::L}},
    {1253, {"E Limb Cover 03"_s,        Accessory::Size::L}},
    {1254, {"E Limb Cover 04"_s,        Accessory::Size::L}},
    {1255, {"E Limb Cover 05"_s,        Accessory::Size::L}},
    {1256, {"E Limb Cover 06"_s,        Accessory::Size::L}},
    {1257, {"E Limb Cover 07"_s,        Accessory::Size::L}},
    {1258, {"E Limb Cover 08"_s,        Accessory::Size::L}},
    {1259, {"E Limb Cover 09"_s,        Accessory::Size::L}},
    {1260, {"E Limb Cover 10"_s,        Accessory::Size::L}},

    {1301, {"C Limb Cover 01"_s,        Accessory::Size::L}},
    {1302, {"C Limb Cover 02"_s,        Accessory::Size::L}},
    {1303, {"C Limb Cover 03"_s,        Accessory::Size::L}},
    {1304, {"C Limb Cover 04"_s,        Accessory::Size::L}},
    {1305, {"C Limb Cover 05"_s,        Accessory::Size::L}},
    {1306, {"C Limb Cover 06"_s,        Accessory::Size::L}},
    {1307, {"C Limb Cover 07"_s,        Accessory::Size::L}},
    {1308, {"C Limb Cover 08"_s,        Accessory::Size::L}},
    {1309, {"C Limb Cover 09"_s,        Accessory::Size::L}},
    {1310, {"C Limb Cover 10"_s,        Accessory::Size::L}},
    {1311, {"C Limb Cover 11"_s,        Accessory::Size::L}},
    {1312, {"C Limb Cover 12"_s,        Accessory::Size::L}},
    {1313, {"C Limb Cover 13"_s,        Accessory::Size::L}},
    {1314, {"C Limb Cover 14"_s,        Accessory::Size::L}},
    {1315, {"C Limb Cover 15"_s,        Accessory::Size::L}},
    {1316, {"C Limb Cover 16"_s,        Accessory::Size::L}},
    {1317, {"C Limb Cover 17"_s,        Accessory::Size::L}},
    {1318, {"C Limb Cover 18"_s,        Accessory::Size::L}},
    {1319, {"C Limb Cover 19"_s,        Accessory::Size::L}},
    {1320, {"C Limb Cover 20"_s,        Accessory::Size::L}},

    {1351, {"P Limb Cover 01"_s,        Accessory::Size::XL}},
    {1352, {"P Limb Cover 02"_s,        Accessory::Size::XL}},
    {1353, {"P Limb Cover 03"_s,        Accessory::Size::XL}},
    {1354, {"P Limb Cover 04"_s,        Accessory::Size::XL}},
    {1355, {"P Limb Cover 05"_s,        Accessory::Size::XL}},

    {1401, {"Flat Cover 01"_s,          Accessory::Size::XL}},
    {1402, {"Flat Cover 02"_s,          Accessory::Size::XL}},
    {1403, {"Flat Cover 03"_s,          Accessory::Size::XL}},
    {1404, {"Flat Cover 04"_s,          Accessory::Size::XL}},
    {1405, {"Flat Cover 05"_s,          Accessory::Size::XL}},
    {1406, {"Flat Cover 06"_s,          Accessory::Size::XL}},
    {1407, {"Flat Cover 07"_s,          Accessory::Size::XL}},
    {1408, {"Flat Cover 08"_s,          Accessory::Size::XL}},
    {1409, {"Flat Cover 09"_s,          Accessory::Size::XL}},
    {1410, {"Flat Cover 10"_s,          Accessory::Size::XL}},

    {1451, {"L Side Opening 01"_s,      Accessory::Size::XL}},
    {1452, {"L Side Opening 02"_s,      Accessory::Size::XL}},
    {1453, {"L Side Opening 03"_s,      Accessory::Size::XL}},
    {1454, {"L Side Opening 04"_s,      Accessory::Size::XL}},
    {1455, {"L Side Opening 05"_s,      Accessory::Size::XL}},
    {1456, {"L Side Opening 06"_s,      Accessory::Size::XL}},
    {1457, {"L Side Opening 07"_s,      Accessory::Size::XL}},
    {1458, {"L Side Opening 08"_s,      Accessory::Size::XL}},
    {1459, {"L Side Opening 09"_s,      Accessory::Size::XL}},
    {1460, {"L Side Opening 10"_s,      Accessory::Size::XL}},
    // endregion

    // region Components
    {2001, {"Disc Padding 01"_s,        Accessory::Size::M}},
    {2002, {"Disc Padding 02"_s,        Accessory::Size::M}},
    {2003, {"Disc Padding 03"_s,        Accessory::Size::M}},
    {2004, {"Disc Padding 04"_s,        Accessory::Size::M}},
    {2005, {"Disc Padding 05"_s,        Accessory::Size::M}},
    {2006, {"Thin Padding 01"_s,        Accessory::Size::M}},
    {2007, {"Thin Padding 02"_s,        Accessory::Size::M}},
    {2008, {"Thin Padding 03"_s,        Accessory::Size::M}},
    {2009, {"Thin Padding 04"_s,        Accessory::Size::M}},
    {2010, {"Thin Padding 05"_s,        Accessory::Size::M}},
    {2011, {"Thick Padding 01"_s,       Accessory::Size::M}},
    {2012, {"Thick Padding 02"_s,       Accessory::Size::M}},
    {2013, {"Thick Padding 03"_s,       Accessory::Size::M}},
    {2014, {"Thick Padding 04"_s,       Accessory::Size::M}},
    {2015, {"Thick Padding 05"_s,       Accessory::Size::M}},
    {2016, {"Thick Padding 06"_s,       Accessory::Size::M}},
    {2017, {"Thick Padding 07"_s,       Accessory::Size::M}},
    {2018, {"Thick Padding 08"_s,       Accessory::Size::M}},
    {2019, {"Thick Padding 09"_s,       Accessory::Size::M}},
    {2020, {"Thick Padding 10"_s,       Accessory::Size::M}},
    {2021, {"CSide Padding 01"_s,       Accessory::Size::M}},
    {2022, {"CSide Padding 02"_s,       Accessory::Size::M}},
    {2023, {"CSide Padding 03"_s,       Accessory::Size::M}},
    {2024, {"CSide Padding 04"_s,       Accessory::Size::M}},
    {2025, {"CSide Padding 05"_s,       Accessory::Size::M}},

    {2051, {"Container 01"_s,           Accessory::Size::L}},
    {2052, {"Container 02"_s,           Accessory::Size::L}},
    {2053, {"Container 03"_s,           Accessory::Size::L}},
    {2054, {"Container 04"_s,           Accessory::Size::L}},
    {2055, {"Container 05"_s,           Accessory::Size::L}},

    {2101, {"Plating 01"_s,             Accessory::Size::L}},
    {2102, {"Plating 02"_s,             Accessory::Size::L}},
    {2103, {"Plating 03"_s,             Accessory::Size::L}},
    {2104, {"Plating 04"_s,             Accessory::Size::L}},
    {2105, {"Plating 05"_s,             Accessory::Size::L}},

    {2151, {"Complex Base 01"_s,        Accessory::Size::L}},
    {2152, {"Complex Base 02"_s,        Accessory::Size::L}},
    {2153, {"Complex Base 03"_s,        Accessory::Size::L}},
    {2154, {"Complex Base 04"_s,        Accessory::Size::L}},
    {2155, {"Complex Base 05"_s,        Accessory::Size::L}},
    {2156, {"Complex Base 06"_s,        Accessory::Size::L}},
    {2157, {"Complex Base 07"_s,        Accessory::Size::L}},
    {2158, {"Complex Base 08"_s,        Accessory::Size::L}},
    {2159, {"Complex Base 09"_s,        Accessory::Size::L}},
    {2160, {"Complex Base 10"_s,        Accessory::Size::L}},

    {2201, {"Long Base 01"_s,           Accessory::Size::XL}},
    {2202, {"Long Base 02"_s,           Accessory::Size::XL}},
    {2203, {"Long Base 03"_s,           Accessory::Size::XL}},
    {2204, {"Long Base 04"_s,           Accessory::Size::XL}},
    {2205, {"Long Base 05"_s,           Accessory::Size::XL}},

    {2251, {"Straight Wing 01"_s,       Accessory::Size::XL}},
    {2252, {"Straight Wing 02"_s,       Accessory::Size::XL}},
    {2253, {"Straight Wing 03"_s,       Accessory::Size::XL}},
    {2254, {"Straight Wing 04"_s,       Accessory::Size::XL}},
    {2255, {"Straight Wing 05"_s,       Accessory::Size::XL}},
    {2256, {"Straight Wing 06"_s,       Accessory::Size::XL}},
    {2257, {"Straight Wing 07"_s,       Accessory::Size::XL}},
    {2258, {"Straight Wing 08"_s,       Accessory::Size::XL}},
    {2259, {"Straight Wing 09"_s,       Accessory::Size::XL}},
    {2260, {"Straight Wing 10"_s,       Accessory::Size::XL}},

    {2301, {"Triangular Wing 01"_s,     Accessory::Size::XL}},
    {2302, {"Triangular Wing 02"_s,     Accessory::Size::XL}},
    {2303, {"Triangular Wing 03"_s,     Accessory::Size::XL}},
    {2304, {"Triangular Wing 04"_s,     Accessory::Size::XL}},
    {2305, {"Triangular Wing 05"_s,     Accessory::Size::XL}},
    {2306, {"Triangular Wing 06"_s,     Accessory::Size::XL}},
    {2307, {"Triangular Wing 07"_s,     Accessory::Size::XL}},
    {2308, {"Triangular Wing 08"_s,     Accessory::Size::XL}},
    {2309, {"Triangular Wing 09"_s,     Accessory::Size::XL}},
    {2310, {"Triangular Wing 10"_s,     Accessory::Size::XL}},
    {2311, {"Triangular Wing 11"_s,     Accessory::Size::L}},
    {2312, {"Triangular Wing 12"_s,     Accessory::Size::L}},
    {2313, {"Triangular Wing 13"_s,     Accessory::Size::L}},
    {2314, {"Triangular Wing 14"_s,     Accessory::Size::L}},
    {2315, {"Triangular Wing 15"_s,     Accessory::Size::L}},

    {2351, {"Complex Wing 01"_s,        Accessory::Size::XL}},
    {2352, {"Complex Wing 02"_s,        Accessory::Size::XL}},
    {2353, {"Complex Wing 03"_s,        Accessory::Size::XL}},
    {2354, {"Complex Wing 04"_s,        Accessory::Size::XL}},
    {2355, {"Complex Wing 05"_s,        Accessory::Size::XL}},
    {2356, {"Complex Wing 06"_s,        Accessory::Size::L}},
    {2357, {"Complex Wing 07"_s,        Accessory::Size::L}},
    {2358, {"Complex Wing 08"_s,        Accessory::Size::L}},
    {2359, {"Complex Wing 09"_s,        Accessory::Size::L}},
    {2360, {"Complex Wing 10"_s,        Accessory::Size::L}},

    {2401, {"Blade 01"_s,               Accessory::Size::XL}},
    {2402, {"Blade 02"_s,               Accessory::Size::XL}},
    {2403, {"Blade 03"_s,               Accessory::Size::XL}},
    {2404, {"Blade 04"_s,               Accessory::Size::XL}},
    {2405, {"Blade 05"_s,               Accessory::Size::XL}},
    {2406, {"Blade 06"_s,               Accessory::Size::XL}},
    {2407, {"Blade 07"_s,               Accessory::Size::XL}},
    {2408, {"Blade 08"_s,               Accessory::Size::XL}},
    {2409, {"Blade 09"_s,               Accessory::Size::XL}},
    {2410, {"Blade 10"_s,               Accessory::Size::XL}},
    {2411, {"Blade 11"_s,               Accessory::Size::XL}},
    {2412, {"Blade 12"_s,               Accessory::Size::XL}},
    {2413, {"Blade 13"_s,               Accessory::Size::XL}},
    {2414, {"Blade 14"_s,               Accessory::Size::XL}},
    {2415, {"Blade 15"_s,               Accessory::Size::XL}},

    {2426, {"Curved Blade 01"_s,        Accessory::Size::XL}},
    {2427, {"Curved Blade 02"_s,        Accessory::Size::XL}},
    {2428, {"Curved Blade 03"_s,        Accessory::Size::XL}},
    {2429, {"Curved Blade 04"_s,        Accessory::Size::XL}},
    {2430, {"Curved Blade 05"_s,        Accessory::Size::XL}},
    {2431, {"Axe Head 01"_s,            Accessory::Size::XL}},
    {2432, {"Axe Head 02"_s,            Accessory::Size::XL}},
    {2433, {"Axe Head 03"_s,            Accessory::Size::XL}},
    {2434, {"Axe Head 04"_s,            Accessory::Size::XL}},
    {2435, {"Axe Head 05"_s,            Accessory::Size::XL}},

    {2451, {"Horn 01"_s,                Accessory::Size::M}},
    {2452, {"Horn 02"_s,                Accessory::Size::M}},
    {2453, {"Horn 03"_s,                Accessory::Size::M}},
    {2454, {"Horn 04"_s,                Accessory::Size::M}},
    {2455, {"Horn 05"_s,                Accessory::Size::M}},
    {2456, {"Horn 06"_s,                Accessory::Size::M}},
    {2457, {"Horn 07"_s,                Accessory::Size::M}},
    {2458, {"Horn 08"_s,                Accessory::Size::M}},
    {2459, {"Horn 09"_s,                Accessory::Size::M}},
    {2460, {"Horn 10"_s,                Accessory::Size::M}},
    {2461, {"Horn 11"_s,                Accessory::Size::M}},
    {2462, {"Horn 12"_s,                Accessory::Size::M}},
    {2463, {"Horn 13"_s,                Accessory::Size::M}},
    {2464, {"Horn 14"_s,                Accessory::Size::M}},
    {2465, {"Horn 15"_s,                Accessory::Size::M}},

    {2471, {"Mask"_s,                   Accessory::Size::M}},
    {2472, {"Droplet"_s,                Accessory::Size::M}},
    {2473, {"Thigh"_s,                  Accessory::Size::M}},
    {2474, {"LegS"_s,                   Accessory::Size::M}},
    {2475, {"LegTH"_s,                  Accessory::Size::M}},
    {2476, {"Plume 01"_s,               Accessory::Size::M}},
    {2477, {"Plume 02"_s,               Accessory::Size::M}},
    {2478, {"Plume 03"_s,               Accessory::Size::M}},
    {2479, {"Plume 04"_s,               Accessory::Size::M}},
    {2480, {"Plume 05"_s,               Accessory::Size::M}},

    {2491, {"Tail 01"_s,                Accessory::Size::XL}},
    {2492, {"Tail 02"_s,                Accessory::Size::XL}},
    {2493, {"Tail 03"_s,                Accessory::Size::XL}},
    {2494, {"Tail 04"_s,                Accessory::Size::XL}},
    {2495, {"Tail 05"_s,                Accessory::Size::XL}},

    {2501, {"Finger 01"_s,              Accessory::Size::M}},
    {2502, {"Finger 02"_s,              Accessory::Size::M}},
    {2503, {"Finger 03"_s,              Accessory::Size::M}},
    {2504, {"Finger 04"_s,              Accessory::Size::M}},
    {2505, {"Finger 05"_s,              Accessory::Size::M}},

    {2510, {"Clamp 01"_s,               Accessory::Size::M}},
    {2511, {"Clamp 02"_s,               Accessory::Size::M}},
    {2512, {"Clamp 03"_s,               Accessory::Size::M}},
    {2513, {"Clamp 04"_s,               Accessory::Size::M}},
    {2514, {"Clamp 05"_s,               Accessory::Size::M}},

    {2521, {"Fabric 01"_s,              Accessory::Size::XL}},
    {2522, {"Fabric 02"_s,              Accessory::Size::XL}},
    {2523, {"Fabric 03"_s,              Accessory::Size::XL}},
    {2524, {"Fabric 04"_s,              Accessory::Size::XL}},
    {2525, {"Fabric 05"_s,              Accessory::Size::XL}},

    {2551, {"Energy Barrel 01"_s,       Accessory::Size::XL}},
    {2552, {"Energy Barrel 02"_s,       Accessory::Size::XL}},
    {2553, {"Energy Barrel 03"_s,       Accessory::Size::XL}},
    {2554, {"Energy Barrel 04"_s,       Accessory::Size::XL}},
    {2555, {"Energy Barrel 05"_s,       Accessory::Size::XL}},

    {2601, {"L Bullet Barrel 01"_s,     Accessory::Size::XL}},
    {2602, {"L Bullet Barrel 02"_s,     Accessory::Size::XL}},
    {2603, {"L Bullet Barrel 03"_s,     Accessory::Size::XL}},
    {2604, {"L Bullet Barrel 04"_s,     Accessory::Size::XL}},
    {2605, {"L Bullet Barrel 05"_s,     Accessory::Size::XL}},
    {2606, {"S Bullet Barrel 01"_s,     Accessory::Size::XL}},
    {2607, {"S Bullet Barrel 02"_s,     Accessory::Size::XL}},
    {2608, {"S Bullet Barrel 03"_s,     Accessory::Size::XL}},
    {2609, {"S Bullet Barrel 04"_s,     Accessory::Size::XL}},
    {2610, {"S Bullet Barrel 05"_s,     Accessory::Size::XL}},
    {2611, {"B Bullet Barrel 01"_s,     Accessory::Size::XL}},
    {2612, {"B Bullet Barrel 02"_s,     Accessory::Size::XL}},
    {2613, {"B Bullet Barrel 03"_s,     Accessory::Size::XL}},
    {2614, {"B Bullet Barrel 04"_s,     Accessory::Size::XL}},
    {2615, {"B Bullet Barrel 05"_s,     Accessory::Size::XL}},
    {2616, {"B Bullet Barrel 06"_s,     Accessory::Size::XL}},
    {2617, {"B Bullet Barrel 07"_s,     Accessory::Size::XL}},
    {2618, {"B Bullet Barrel 08"_s,     Accessory::Size::XL}},
    {2619, {"B Bullet Barrel 09"_s,     Accessory::Size::XL}},
    {2620, {"B Bullet Barrel 10"_s,     Accessory::Size::XL}},

    {2651, {"Cylinder Scope 01"_s,      Accessory::Size::M}},
    {2652, {"Cylinder Scope 02"_s,      Accessory::Size::M}},
    {2653, {"Cylinder Scope 03"_s,      Accessory::Size::M}},
    {2654, {"Cylinder Scope 04"_s,      Accessory::Size::M}},
    {2655, {"Cylinder Scope 05"_s,      Accessory::Size::M}},
    {2656, {"Elec Scope 01"_s,          Accessory::Size::M}},
    {2657, {"Elec Scope 02"_s,          Accessory::Size::M}},
    {2658, {"Elec Scope 03"_s,          Accessory::Size::M}},
    {2659, {"Elec Scope 04"_s,          Accessory::Size::M}},
    {2660, {"Elec Scope 05"_s,          Accessory::Size::M}},
    {2661, {"Mark Scope 01"_s,          Accessory::Size::S}},
    {2662, {"Mark Scope 02"_s,          Accessory::Size::S}},
    {2663, {"Mark Scope 03"_s,          Accessory::Size::S}},
    {2664, {"Mark Scope 04"_s,          Accessory::Size::S}},
    {2665, {"Mark Scope 05"_s,          Accessory::Size::S}},

    {2701, {"S Single Weaponry"_s,      Accessory::Size::M}},
    {2702, {"S Packed Weaponry 01"_s,   Accessory::Size::M}},
    {2703, {"S Packed Weaponry 02"_s,   Accessory::Size::M}},
    {2704, {"S Packed Weaponry 03"_s,   Accessory::Size::M}},
    {2705, {"S Packed Weaponry 04"_s,   Accessory::Size::M}},
    {2706, {"L Single Weaponry"_s,      Accessory::Size::XL}},
    {2707, {"L Packed Weaponry 01"_s,   Accessory::Size::XL}},
    {2708, {"L Packed Weaponry 02"_s,   Accessory::Size::XL}},
    {2709, {"L Packed Weaponry 03"_s,   Accessory::Size::XL}},
    {2710, {"L Packed Weaponry 04"_s,   Accessory::Size::XL}},
    {2711, {"Atk Single Weaponry"_s,    Accessory::Size::XL}},
    {2712, {"Atk Packed Weaponry 01"_s, Accessory::Size::XL}},
    {2713, {"Atk Packed Weaponry 02"_s, Accessory::Size::XL}},
    {2714, {"Atk Packed Weaponry 03"_s, Accessory::Size::XL}},
    {2715, {"Atk Packed Weaponry 04"_s, Accessory::Size::XL}},

    {2751, {"Vent 01"_s,                Accessory::Size::M}},
    {2752, {"Vent 02"_s,                Accessory::Size::M}},
    {2753, {"Vent 03"_s,                Accessory::Size::M}},
    {2754, {"Vent 04"_s,                Accessory::Size::M}},
    {2755, {"Vent 05"_s,                Accessory::Size::M}},
    {2756, {"Vent 06"_s,                Accessory::Size::M}},
    {2757, {"Vent 07"_s,                Accessory::Size::M}},
    {2758, {"Vent 08"_s,                Accessory::Size::M}},
    {2759, {"Vent 09"_s,                Accessory::Size::M}},
    {2760, {"Vent 10"_s,                Accessory::Size::M}},

    {2901, {"Complex Construct 01"_s,   Accessory::Size::L}},
    {2902, {"Complex Construct 02"_s,   Accessory::Size::L}},
    {2903, {"Complex Construct 03"_s,   Accessory::Size::L}},
    {2904, {"Complex Construct 04"_s,   Accessory::Size::L}},
    {2905, {"Complex Construct 05"_s,   Accessory::Size::L}},

    {2950, {"Q Mask 01"_s,              Accessory::Size::M}},
    {2951, {"Q Mask 02"_s,              Accessory::Size::M}},
    {2952, {"Q Mask 03"_s,              Accessory::Size::M}},
    {2953, {"Q Mask 04"_s,              Accessory::Size::M}},
    {2954, {"Q Mask 05"_s,              Accessory::Size::M}},
    // endregion

    // region Connectors
    {3001, {"Circular Vent 01"_s,       Accessory::Size::M}},
    {3002, {"Circular Vent 02"_s,       Accessory::Size::M}},
    {3003, {"Circular Vent 03"_s,       Accessory::Size::M}},
    {3004, {"Circular Vent 04"_s,       Accessory::Size::M}},
    {3005, {"Circular Vent 05"_s,       Accessory::Size::M}},
    {3006, {"Circular Vent 06"_s,       Accessory::Size::M}},
    {3007, {"Circular Vent 07"_s,       Accessory::Size::M}},
    {3008, {"Circular Vent 08"_s,       Accessory::Size::M}},
    {3009, {"Circular Vent 09"_s,       Accessory::Size::M}},
    {3010, {"Circular Vent 10"_s,       Accessory::Size::M}},
    {3011, {"Circular Vent 11"_s,       Accessory::Size::M}},
    {3012, {"Circular Vent 12"_s,       Accessory::Size::M}},
    {3013, {"Circular Vent 13"_s,       Accessory::Size::M}},
    {3014, {"Circular Vent 14"_s,       Accessory::Size::M}},
    {3015, {"Circular Vent 15"_s,       Accessory::Size::M}},

    {3051, {"Reactor 01"_s,             Accessory::Size::L}},
    {3052, {"Reactor 02"_s,             Accessory::Size::L}},
    {3053, {"Reactor 03"_s,             Accessory::Size::L}},
    {3054, {"Reactor 04"_s,             Accessory::Size::L}},
    {3055, {"Reactor 05"_s,             Accessory::Size::L}},

    {3101, {"Connecting Tube 01"_s,     Accessory::Size::XL}},
    {3102, {"Connecting Tube 02"_s,     Accessory::Size::XL}},
    {3103, {"Connecting Tube 03"_s,     Accessory::Size::XL}},
    {3104, {"Connecting Tube 04"_s,     Accessory::Size::XL}},
    {3105, {"Connecting Tube 05"_s,     Accessory::Size::XL}},

    {3151, {"Latch 01"_s,               Accessory::Size::M}},
    {3152, {"Latch 02"_s,               Accessory::Size::M}},
    {3153, {"Latch 03"_s,               Accessory::Size::M}},
    {3154, {"Latch 04"_s,               Accessory::Size::M}},
    {3155, {"Latch 05"_s,               Accessory::Size::M}},
    {3156, {"Latch 06"_s,               Accessory::Size::M}},
    {3157, {"Latch 07"_s,               Accessory::Size::M}},
    {3158, {"Latch 08"_s,               Accessory::Size::M}},
    {3159, {"Latch 09"_s,               Accessory::Size::M}},
    {3160, {"Latch 10"_s,               Accessory::Size::M}},
    {3161, {"Latch 11"_s,               Accessory::Size::M}},
    {3162, {"Latch 12"_s,               Accessory::Size::M}},
    {3163, {"Latch 13"_s,               Accessory::Size::M}},
    {3164, {"Latch 14"_s,               Accessory::Size::M}},
    {3165, {"Latch 15"_s,               Accessory::Size::M}},

    {3201, {"Short Connector 01"_s,     Accessory::Size::M}},
    {3202, {"Short Connector 02"_s,     Accessory::Size::M}},
    {3203, {"Short Connector 03"_s,     Accessory::Size::M}},
    {3204, {"Short Connector 04"_s,     Accessory::Size::M}},
    {3205, {"Short Connector 05"_s,     Accessory::Size::M}},
    {3206, {"Antenna 01"_s,             Accessory::Size::S}},
    {3207, {"Antenna 02"_s,             Accessory::Size::S}},
    {3208, {"Antenna 03"_s,             Accessory::Size::S}},
    {3209, {"Antenna 04"_s,             Accessory::Size::S}},
    {3210, {"Antenna 05"_s,             Accessory::Size::S}},

    {3226, {"Long Connector 01"_s,      Accessory::Size::XL}},
    {3227, {"Long Connector 02"_s,      Accessory::Size::XL}},
    {3228, {"Long Connector 03"_s,      Accessory::Size::XL}},
    {3229, {"Long Connector 04"_s,      Accessory::Size::XL}},
    {3230, {"Long Connector 05"_s,      Accessory::Size::XL}},
    {3231, {"Long Connector 06"_s,      Accessory::Size::XL}},
    {3232, {"Long Connector 07"_s,      Accessory::Size::XL}},
    {3233, {"Long Connector 08"_s,      Accessory::Size::XL}},
    {3234, {"Long Connector 09"_s,      Accessory::Size::XL}},
    {3235, {"Long Connector 10"_s,      Accessory::Size::XL}},

    {3251, {"Complex Connector 01"_s,   Accessory::Size::XL}},
    {3252, {"Complex Connector 02"_s,   Accessory::Size::XL}},
    {3253, {"Complex Connector 03"_s,   Accessory::Size::XL}},
    {3254, {"Complex Connector 04"_s,   Accessory::Size::XL}},
    {3255, {"Complex Connector 05"_s,   Accessory::Size::XL}},

    {3301, {"Tube Line 01"_s,           Accessory::Size::L}},
    {3302, {"Tube Line 02"_s,           Accessory::Size::L}},
    {3303, {"Tube Line 03"_s,           Accessory::Size::L}},
    {3304, {"Tube Line 04"_s,           Accessory::Size::XL}},
    {3305, {"Tube Line 05"_s,           Accessory::Size::XL}},
    {3306, {"Tube Line 06"_s,           Accessory::Size::M}},
    {3307, {"Tube Line 07"_s,           Accessory::Size::M}},
    {3308, {"Tube Line 08"_s,           Accessory::Size::M}},
    {3309, {"Tube Line 09"_s,           Accessory::Size::L}},
    {3310, {"Tube Line 10"_s,           Accessory::Size::L}},

    {3351, {"Radar Plate 01"_s,         Accessory::Size::M}},
    {3352, {"Radar Plate 02"_s,         Accessory::Size::M}},
    {3353, {"Radar Plate 03"_s,         Accessory::Size::M}},
    {3354, {"Radar Plate 04"_s,         Accessory::Size::M}},
    {3355, {"Radar Plate 05"_s,         Accessory::Size::M}},
    {3356, {"Radar Pod 01"_s,           Accessory::Size::M}},
    {3357, {"Radar Pod 02"_s,           Accessory::Size::M}},
    {3358, {"Radar Pod 03"_s,           Accessory::Size::M}},
    {3359, {"Radar Pod 04"_s,           Accessory::Size::M}},
    {3360, {"Radar Pod 05"_s,           Accessory::Size::M}},

    {3401, {"Tri Pod 01"_s,             Accessory::Size::M}},
    {3402, {"Tri Pod 02"_s,             Accessory::Size::M}},
    {3403, {"Tri Pod 03"_s,             Accessory::Size::M}},
    {3404, {"Tri Pod 04"_s,             Accessory::Size::M}},
    {3405, {"Tri Pod 05"_s,             Accessory::Size::M}},
    {3406, {"Signal Pod 01"_s,          Accessory::Size::M}},
    {3407, {"Signal Pod 02"_s,          Accessory::Size::M}},
    {3408, {"Signal Pod 03"_s,          Accessory::Size::M}},
    {3409, {"Signal Pod 04"_s,          Accessory::Size::M}},
    {3410, {"Signal Pod 05"_s,          Accessory::Size::M}},
    // endregion
};

}}
