#pragma once

// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include <Corrade/Containers/Array.h>
#include <Corrade/Containers/StaticArray.h>

#include "Decal.h"
#include "Accessory.h"

using namespace Corrade;

namespace mbst { namespace GameObjects {

struct WeaponPart {
    WeaponPart() = default;

    WeaponPart(const WeaponPart& other) {
        id = other.id;
        styles = other.styles;
        decals = Containers::Array<Decal>{other.decals.size()};
        for(auto i = 0u; i < decals.size(); i++) {
            decals[i] = other.decals[i];
        }
        accessories = Containers::Array<Accessory>{other.accessories.size()};
        for(auto i = 0u; i < accessories.size(); i++) {
            accessories[i] = other.accessories[i];
        }
    }
    WeaponPart& operator=(const WeaponPart& other) {
        id = other.id;
        styles = other.styles;
        decals = Containers::Array<Decal>{other.decals.size()};
        for(auto i = 0u; i < decals.size(); i++) {
            decals[i] = other.decals[i];
        }
        accessories = Containers::Array<Accessory>{other.accessories.size()};
        for(auto i = 0u; i < accessories.size(); i++) {
            accessories[i] = other.accessories[i];
        }
        return *this;
    }

    WeaponPart(WeaponPart&& other) = default;
    WeaponPart& operator=(WeaponPart&& other) = default;

    std::int32_t id = 0;
    Containers::StaticArray<4, std::int32_t> styles{ValueInit};
    Containers::Array<Decal> decals{};
    Containers::Array<Accessory> accessories{};
};

}}
