#pragma once

// MassBuilderSaveTool
// Copyright (C) 2021-2024 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include <cstdint>

#include <string>

#include <Corrade/Containers/Array.h>
#include <Corrade/Containers/String.h>

#include "../Profile/Profile.h"

using namespace Corrade;

namespace mbst {

struct Backup {
    Containers::String filename;
    Containers::String company;
    bool demo;
    struct {
        std::int32_t year;
        std::int32_t month;
        std::int32_t day;
        std::int32_t hour;
        std::int32_t minute;
        std::int32_t second;
    } timestamp;
    Containers::Array<Containers::String> includedFiles;
};

class ProfileManager {
    public:
        explicit ProfileManager(Containers::StringView save_dir, Containers::StringView backup_dir);

        auto ready() const -> bool;
        auto lastError() -> Containers::StringView;

        auto profiles() -> Containers::ArrayView<GameObjects::Profile>;
        bool refreshProfiles();

        auto getProfile(std::size_t index) -> GameObjects::Profile*;
        bool deleteProfile(std::size_t index, bool delete_builds);
        bool backupProfile(std::size_t index, bool backup_builds);

        auto backups() -> Containers::ArrayView<Backup>;
        void refreshBackups();

        bool deleteBackup(std::size_t index);
        bool restoreBackup(std::size_t index);

    private:
        bool _ready = false;
        Containers::String _lastError;

        Containers::StringView _saveDirectory;
        Containers::StringView _backupsDirectory;

        Containers::Array<GameObjects::Profile> _profiles;
        Containers::Array<Backup> _backups;
};

}
